@@ -15,8 +15,13 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  */
+
 #include "config.h"
 
+#include <glib.h>
+
+#include "apptypes.h"
+
 #include "appenv.h"
 #include "about_dialog.h"
 #include "app_procs.h"
@@ -35,7 +40,6 @@
 #include "fileops.h"
 #include "floating_sel.h"
 #include "gdisplay_ops.h"
-#include "gdisplay_color_ui.h"
 #include "gimage_mask.h"
 #include "gimphelp.h"
 #include "gimprc.h"
@@ -58,6 +62,10 @@
 #include "tools.h"
 #include "undo.h"
 
+#ifdef DISPLAY_FILTERS
+#include "gdisplay_color_ui.h"
+#endif /* DISPLAY_FILTERS */
+
 #include "libgimp/gimpmath.h"
 #include "libgimp/gimpintl.h"
 
@@ -1213,6 +1221,7 @@ dialogs_error_console_cmd_callback (GtkWidget *widget,
   error_console_add (NULL);
 }
 
+#ifdef DISPLAY_FILTERS
 void
 dialogs_display_filters_cmd_callback (GtkWidget *widget,
 				      gpointer   client_data)
@@ -1231,6 +1240,7 @@ dialogs_display_filters_cmd_callback (GtkWidget *widget,
   else
     gdk_window_raise (gdisp->cd_ui->window);
 }
+#endif /* DISPLAY_FILTERS */
 
 void
 dialogs_undo_history_cmd_callback (GtkWidget *widget,
@@ -1318,6 +1328,7 @@ image_resize_callback (GtkWidget *widget,
 			 image_resize->resize->offset_x,
 			 image_resize->resize->offset_y);
 	  gdisplays_flush ();
+	  lc_dialog_update_image_list ();
 	}
       else 
 	{
