@@ -15,28 +15,25 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  */
+
 #ifndef __PALETTE_H__
 #define __PALETTE_H__
 
-#include <glib.h>
 
 /*  The states for updating a color in the palette via palette_set_* calls */
 #define COLOR_NEW         0
 #define COLOR_UPDATE_NEW  1
 #define COLOR_UPDATE      2
 
-void   palettes_init            (gint  no_data);
-void   palette_init_palettes    (gint  no_data);
-
+void   palettes_init            (gboolean no_data);
 void   palettes_free            (void);
-void   palette_free_palettes    (void);
 
 void   palette_dialog_create    (void);
 void   palette_dialog_free      (void);
 
-void   palette_set_active_color (gint  r,
-				 gint  g,
-				 gint  b,
-				 gint  state);
+void   palette_set_active_color (gint     r,
+				 gint     g,
+				 gint     b,
+				 gint     state);
 
 #endif /* __PALETTE_H__ */
