@@ -15,6 +15,9 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  */
+
+#include "config.h"
+
 #include <stdlib.h>
 #include <string.h>
 
@@ -27,6 +30,8 @@
 
 #include <gdk/gdkprivate.h>
 
+#include "apptypes.h"
+
 #include "appenv.h"
 #include "drawable.h"
 #include "edit_selection.h"
@@ -115,8 +120,8 @@ static void   text_gdk_image_to_region (GdkImage *, gint, PixelRegion *);
 static void   text_size_multiply       (gchar **fontname, gint);
 static void   text_set_resolution      (gchar **fontname, gdouble, gdouble);
 
-Layer       * text_render (GImage *, GimpDrawable *,
-			   gint, gint, gchar *, gchar *, gint, gint);
+/*  Layer       * text_render (GImage *, GimpDrawable *, */
+/*  			   gint, gint, gchar *, gchar *, gint, gint); */
 
 
 /*  functions  */
@@ -214,10 +219,10 @@ text_options_new (void)
   gtk_widget_set_sensitive (spinbutton, ! options->use_dyntext_d);
   gtk_widget_set_sensitive (label, ! options->use_dyntext_d);
   gtk_object_set_data (GTK_OBJECT (options->use_dyntext_w), "inverse_sensitive",
-		       options->antialias_w);
-  gtk_object_set_data (GTK_OBJECT (options->antialias_w), "inverse_sensitive",
 		       spinbutton);
   gtk_object_set_data (GTK_OBJECT (spinbutton), "inverse_sensitive", label);
+  gtk_object_set_data (GTK_OBJECT (label), "inverse_sensitive",
+		       options->antialias_w);
 
   return options;
 }
@@ -256,8 +261,8 @@ tools_free_text (Tool *tool)
   g_free (tool->private);
   the_text_tool = NULL;
 
-  if (text_tool_shell && GTK_WIDGET_VISIBLE (text_tool_shell))
-    gtk_widget_hide (text_tool_shell);
+  if (text_tool_shell)
+    gimp_dialog_hide (text_tool_shell);
 }
 
 static void
@@ -314,7 +319,7 @@ text_button_press (Tool           *tool,
     /*  If there is a floating selection, and this aint it, use the move tool  */
     if (layer_is_floating_sel (layer))
       {
-	init_edit_selection (tool, gdisp_ptr, bevent, LayerTranslate);
+	init_edit_selection (tool, gdisp_ptr, bevent, EDIT_LAYER_TRANSLATE);
 	return;
       }
 
@@ -350,17 +355,24 @@ text_cursor_update (Tool           *tool,
 
   gdisp = (GDisplay *) gdisp_ptr;
 
-  gdisplay_untransform_coords (gdisp, mevent->x, mevent->y, &x, &y, FALSE, FALSE);
+  gdisplay_untransform_coords (gdisp, mevent->x, mevent->y,
+			       &x, &y, FALSE, FALSE);
 
   if ((layer = gimage_pick_correlate_layer (gdisp->gimage, x, y)))
     /*  if there is a floating selection, and this aint it...  */
     if (layer_is_floating_sel (layer))
       {
-	gdisplay_install_tool_cursor (gdisp, GDK_FLEUR);
+	gdisplay_install_tool_cursor (gdisp, GDK_FLEUR,
+				      MOVE,
+				      CURSOR_MODIFIER_NONE,
+				      FALSE);
 	return;
       }
 
-  gdisplay_install_tool_cursor (gdisp, GDK_XTERM);
+  gdisplay_install_tool_cursor (gdisp, GDK_XTERM,
+				TEXT,
+				CURSOR_MODIFIER_NONE,
+				FALSE);
 }
 
 static void
@@ -377,8 +389,8 @@ text_control (Tool       *tool,
       break;
 
     case HALT:
-      if (text_tool_shell && GTK_WIDGET_VISIBLE (text_tool_shell))
-	gtk_widget_hide (text_tool_shell);
+      if (text_tool_shell)
+	gimp_dialog_hide (text_tool_shell);
       break;
 
     default:
@@ -419,8 +431,7 @@ static void
 text_dialog_ok_callback (GtkWidget *widget,
 			 gpointer   data)
 {
-  if (GTK_WIDGET_VISIBLE (text_tool_shell))
-    gtk_widget_hide (text_tool_shell);
+  gimp_dialog_hide (text_tool_shell);
 
   if (the_text_tool)
     text_init_render (the_text_tool);
@@ -440,8 +451,7 @@ static void
 text_dialog_cancel_callback (GtkWidget *widget,
 			     gpointer   data)
 {
-  if (GTK_WIDGET_VISIBLE (text_tool_shell))
-    gtk_widget_hide (text_tool_shell);
+  gimp_dialog_hide (text_tool_shell);
 }
 
 static void
@@ -498,7 +508,7 @@ text_init_render (TextTool *text_tool)
 
 static void
 text_gdk_image_to_region (GdkImage    *image,
-			  int          scale,
+			  gint         scale,
 			  PixelRegion *textPR)
 {
   GdkColor black;
@@ -546,12 +556,12 @@ text_gdk_image_to_region (GdkImage    *image,
 GimpLayer *
 text_render (GimpImage    *gimage,
 	     GimpDrawable *drawable,
-	     int           text_x,
-	     int           text_y,
-	     char         *fontname,
-	     char         *text,
-	     int           border,
-	     int           antialias)
+	     gint          text_x,
+	     gint          text_y,
+	     gchar        *fontname,
+	     gchar        *text,
+	     gint          border,
+	     gint          antialias)
 {
   GdkFont *font;
   GdkPixmap *pixmap;
@@ -565,17 +575,16 @@ text_render (GimpImage    *gimage,
   guchar color[MAX_CHANNELS];
   gchar *str;
   gint nstrs;
-  gint crop;
+  gboolean crop;
   gint line_width, line_height;
   gint pixmap_width, pixmap_height;
   gint text_width, text_height;
   gint width, height;
   gint x, y, k;
-  void * pr;
+  void *pr;
 #ifndef GDK_WINDOWING_WIN32
   XFontStruct *xfs;
 #endif
-  char *fname;
 
   /*  determine the layer type  */
   if (drawable)
@@ -587,24 +596,33 @@ text_render (GimpImage    *gimage,
   if (antialias)
     antialias = SUPERSAMPLE;
   else
-    antialias = TRUE;
+    antialias = 1;
 
   /* Dont crop the text if border is negative */
   crop = (border >= 0);
-  if (!crop) border = 0;
+  if (!crop) 
+    border = 0;
 
   /* load the font in */
   gdk_error_warnings = 0;
   gdk_error_code = 0;
 #ifndef GDK_WINDOWING_WIN32
   font = gdk_font_load (fontname);
-  xfs = GDK_FONT_XFONT(font);
-  if (xfs->min_byte1 != 0 || xfs->max_byte1 != 0) {
-    gdk_font_unref(font);
-    fname = g_strdup_printf("%s,*", fontname);
-    font = gdk_fontset_load (fname);
-    g_free(fname);
-  }
+  if (!font)
+    {
+      g_message (_("Font '%s' not found."), fontname);
+      return NULL;
+    }
+  xfs = GDK_FONT_XFONT (font);
+  if (xfs->min_byte1 != 0 || xfs->max_byte1 != 0) 
+    {
+      gchar *fname;
+
+      gdk_font_unref (font);
+      fname = g_strdup_printf ("%s,*", fontname);
+      font = gdk_fontset_load (fname);
+      g_free (fname);
+    }
 #else
   /* Just use gdk_fontset_load all the time. IMHO it could be like
    * this on all platforms?
@@ -616,7 +634,7 @@ text_render (GimpImage    *gimage,
     {
       g_message (_("Font '%s' not found.%s"),
 		 fontname,
-		 antialias ?
+		 antialias > 1 ?
 		 _("\nIf you don't have scalable fonts, "
 		   "try turning off antialiasing in the tool options.") : "");
       return NULL;
@@ -685,7 +703,9 @@ text_render (GimpImage    *gimage,
   mask = tile_manager_new (text_width, text_height, 1);
   pixel_region_init (&maskPR, mask, 0, 0, text_width, text_height, TRUE);
 
-  for (pr = pixel_regions_register (1, &maskPR); pr != NULL; pr = pixel_regions_process (pr))
+  for (pr = pixel_regions_register (1, &maskPR); 
+       pr != NULL; 
+       pr = pixel_regions_process (pr))
     {
       /* erase the pixmap */
       gdk_gc_set_foreground (gc, &white);
@@ -798,23 +818,46 @@ text_render (GimpImage    *gimage,
   return layer;
 }
 
-int
-text_get_extents (char *fontname,
-		  char *text,
-		  int  *width,
-		  int  *height,
-		  int  *ascent,
-		  int  *descent)
+gboolean
+text_get_extents (gchar *fontname,
+		  gchar *text,
+		  gint  *width,
+		  gint  *height,
+		  gint  *ascent,
+		  gint  *descent)
 {
   GdkFont *font;
   gchar *str;
   gint   nstrs;
   gint   line_width, line_height;
+#ifndef GDK_WINDOWING_WIN32
+  XFontStruct *xfs;
+#endif
 
   /* load the font in */
   gdk_error_warnings = 0;
   gdk_error_code = 0;
+#ifndef GDK_WINDOWING_WIN32
   font = gdk_font_load (fontname);
+  if (!font)
+    return FALSE;
+
+  xfs = GDK_FONT_XFONT (font);
+  if (xfs->min_byte1 != 0 || xfs->max_byte1 != 0) 
+    {
+      gchar *fname;
+
+      gdk_font_unref (font);
+      fname = g_strdup_printf ("%s,*", fontname);
+      font = gdk_fontset_load (fname);
+      g_free (fname);
+    }
+#else
+  /* Just use gdk_fontset_load all the time. IMHO it could be like
+   * this on all platforms?
+   */
+  font = gdk_fontset_load (fontname);
+#endif
   gdk_error_warnings = 1;
   if (!font || (gdk_error_code == -1))
     return FALSE;
