@@ -1,5 +1,5 @@
 /* LIBGIMP - The GIMP Library
- * Copyright (C) 1995-1999 Peter Mattis and Spencer Kimball
+ * Copyright (C) 1995-1997 Peter Mattis and Spencer Kimball
  *
  * gimpwidgets.c
  * Copyright (C) 2000 Michael Natterer <mitch@gimp.org>
@@ -22,6 +22,8 @@
 
 #include "config.h"
 
+#include <gtk/gtk.h>
+
 #include "gimpchainbutton.h"
 #include "gimphelpui.h"
 #include "gimppixmap.h"
@@ -31,6 +33,7 @@
 
 #include "libgimp-intl.h"
 
+
 /*
  *  Widget Constructors
  */
@@ -38,16 +41,15 @@
 /**
  * gimp_option_menu_new:
  * @menu_only: #TRUE if the function should return a #GtkMenu only.
- * @...: A #NULL terminated @va_list describing the menu items.
+ * @...:       A #NULL terminated @va_list describing the menu items.
  *
  * Returns: A #GtkOptionMenu or a #GtkMenu (depending on @menu_only).
- *
- */
+ **/
 GtkWidget *
 gimp_option_menu_new (gboolean            menu_only,
 
 		      /* specify menu items as va_list:
-		       *  gchar          *label,
+		       *  const gchar    *label,
 		       *  GtkSignalFunc   callback,
 		       *  gpointer        data,
 		       *  gpointer        user_data,
@@ -61,7 +63,7 @@ gimp_option_menu_new (gboolean            menu_only,
   GtkWidget *menuitem;
 
   /*  menu item variables  */
-  gchar          *label;
+  const gchar    *label;
   GtkSignalFunc   callback;
   gpointer        data;
   gpointer        user_data;
@@ -76,8 +78,10 @@ gimp_option_menu_new (gboolean            menu_only,
 
   /*  create the menu items  */
   initial_index = 0;
+
   va_start (args, menu_only);
-  label = va_arg (args, gchar*);
+  label = va_arg (args, const gchar *);
+
   for (i = 0; label; i++)
     {
       callback   = va_arg (args, GtkSignalFunc);
@@ -100,6 +104,8 @@ gimp_option_menu_new (gboolean            menu_only,
       else
 	{
 	  menuitem = gtk_menu_item_new ();
+
+	  gtk_widget_set_sensitive (menuitem, FALSE);
 	}
 
       gtk_menu_append (GTK_MENU (menu), menuitem);
@@ -113,7 +119,7 @@ gimp_option_menu_new (gboolean            menu_only,
       if (active)
 	initial_index = i;
 
-      label = va_arg (args, gchar*);
+      label = va_arg (args, const gchar *);
     }
   va_end (args);
 
@@ -135,26 +141,25 @@ gimp_option_menu_new (gboolean            menu_only,
 
 /**
  * gimp_option_menu_new2:
- * @menu_only: #TRUE if the function should return a #GtkMenu only.
+ * @menu_only:          #TRUE if the function should return a #GtkMenu only.
  * @menu_item_callback: The callback each menu item's "activate" signal will
  *                      be connected with.
- * @data: The data which will be passed to gtk_signal_connect().
- * @initial: The @user_data of the initially selected menu item.
- * @...: A #NULL terminated @va_list describing the menu items.
+ * @data:               The data which will be passed to gtk_signal_connect().
+ * @initial:            The @user_data of the initially selected menu item.
+ * @...:                A #NULL terminated @va_list describing the menu items.
  *
  * Returns: A #GtkOptionMenu or a #GtkMenu (depending on @menu_only).
- *
- */
+ **/
 GtkWidget *
-gimp_option_menu_new2 (gboolean        menu_only,
-		       GtkSignalFunc   menu_item_callback,
-		       gpointer        data,
-		       gpointer        initial, /* user_data */
+gimp_option_menu_new2 (gboolean         menu_only,
+		       GtkSignalFunc    menu_item_callback,
+		       gpointer         data,
+		       gpointer         initial, /* user_data */
 
 		       /* specify menu items as va_list:
-			*  gchar      *label,
-			*  gpointer    user_data,
-			*  GtkWidget **widget_ptr,
+			*  const gchar *label,
+			*  gpointer     user_data,
+			*  GtkWidget  **widget_ptr,
 			*/
 
 		       ...)
@@ -163,9 +168,9 @@ gimp_option_menu_new2 (gboolean        menu_only,
   GtkWidget *menuitem;
 
   /*  menu item variables  */
-  gchar      *label;
-  gpointer    user_data;
-  GtkWidget **widget_ptr;
+  const gchar  *label;
+  gpointer      user_data;
+  GtkWidget   **widget_ptr;
 
   va_list args;
   gint    i;
@@ -175,8 +180,10 @@ gimp_option_menu_new2 (gboolean        menu_only,
 
   /*  create the menu items  */
   initial_index = 0;
+
   va_start (args, initial);
-  label = va_arg (args, gchar*);
+  label = va_arg (args, const gchar *);
+
   for (i = 0; label; i++)
     {
       user_data  = va_arg (args, gpointer);
@@ -196,6 +203,8 @@ gimp_option_menu_new2 (gboolean        menu_only,
       else
 	{
 	  menuitem = gtk_menu_item_new ();
+
+	  gtk_widget_set_sensitive (menuitem, FALSE);
 	}
 
       gtk_menu_append (GTK_MENU (menu), menuitem);
@@ -209,7 +218,7 @@ gimp_option_menu_new2 (gboolean        menu_only,
       if (user_data == initial)
 	initial_index = i;
 
-      label = va_arg (args, gchar*);
+      label = va_arg (args, const gchar *);
     }
   va_end (args);
 
@@ -233,9 +242,8 @@ gimp_option_menu_new2 (gboolean        menu_only,
  * gimp_option_menu_set_history:
  * @option_menu: A #GtkOptionMenu as returned by gimp_option_menu_new() or
  *               gimp_option_menu_new2().
- * @user_data: The @user_data of the menu item you want to select.
- *
- */
+ * @user_data:   The @user_data of the menu item you want to select.
+ **/
 void
 gimp_option_menu_set_history (GtkOptionMenu *option_menu,
 			      gpointer       user_data)
@@ -268,19 +276,18 @@ gimp_option_menu_set_history (GtkOptionMenu *option_menu,
 
 /**
  * gimp_radio_group_new:
- * @in_frame: #TRUE if you want a #GtkFrame around the radio button group.
+ * @in_frame:    #TRUE if you want a #GtkFrame around the radio button group.
  * @frame_title: The title of the Frame or #NULL if you don't want a title.
- * @...: A #NULL terminated @va_list describing the radio buttons.
+ * @...:         A #NULL terminated @va_list describing the radio buttons.
  *
  * Returns: A #GtkFrame or #GtkVbox (depending on @in_frame).
- *
- */
+ **/
 GtkWidget *
 gimp_radio_group_new (gboolean            in_frame,
-		      gchar              *frame_title,
+		      const gchar        *frame_title,
 
 		      /* specify radio buttons as va_list:
-		       *  gchar          *label,
+		       *  const gchar    *label,
 		       *  GtkSignalFunc   callback,
 		       *  gpointer        data,
 		       *  gpointer        user_data,
@@ -295,7 +302,7 @@ gimp_radio_group_new (gboolean            in_frame,
   GSList    *group;
 
   /*  radio button variables  */
-  gchar          *label;
+  const gchar    *label;
   GtkSignalFunc   callback;
   gpointer        data;
   gpointer        user_data;
@@ -310,7 +317,7 @@ gimp_radio_group_new (gboolean            in_frame,
 
   /*  create the radio buttons  */
   va_start (args, frame_title);
-  label = va_arg (args, gchar*);
+  label = va_arg (args, const gchar *);
   while (label)
     {
       callback   = va_arg (args, GtkSignalFunc);
@@ -342,7 +349,7 @@ gimp_radio_group_new (gboolean            in_frame,
 
       gtk_widget_show (button);
 
-      label = va_arg (args, gchar*);
+      label = va_arg (args, const gchar *);
     }
   va_end (args);
 
@@ -364,28 +371,31 @@ gimp_radio_group_new (gboolean            in_frame,
 
 /**
  * gimp_radio_group_new2:
- * @in_frame: #TRUE if you want a #GtkFrame around the radio button group.
- * @frame_title: The title of the Frame or #NULL if you don't want a title.
+ * @in_frame:              #TRUE if you want a #GtkFrame around the
+ *                         radio button group.
+ * @frame_title:           The title of the Frame or #NULL if you don't want
+ *                         a title.
  * @radio_button_callback: The callback each button's "toggled" signal will
  *                         be connected with.
- * @data: The data which will be passed to gtk_signal_connect().
- * @initial: The @user_data of the initially pressed radio button.
- * @...: A #NULL terminated @va_list describing the radio buttons.
+ * @data:                  The data which will be passed to
+ *                         gtk_signal_connect().
+ * @initial:               The @user_data of the initially pressed radio button.
+ * @...:                   A #NULL terminated @va_list describing
+ *                         the radio buttons.
  *
  * Returns: A #GtkFrame or #GtkVbox (depending on @in_frame).
- *
- */
+ **/
 GtkWidget *
-gimp_radio_group_new2 (gboolean        in_frame,
-		       gchar          *frame_title,
-		       GtkSignalFunc   radio_button_callback,
-		       gpointer        data,
-		       gpointer        initial, /* user_data */
+gimp_radio_group_new2 (gboolean         in_frame,
+		       const gchar     *frame_title,
+		       GtkSignalFunc    radio_button_callback,
+		       gpointer         data,
+		       gpointer         initial, /* user_data */
 
 		       /* specify radio buttons as va_list:
-			*  gchar      *label,
-			*  gpointer    user_data,
-			*  GtkWidget **widget_ptr,
+			*  const gchar *label,
+			*  gpointer     user_data,
+			*  GtkWidget  **widget_ptr,
 			*/
 
 		       ...)
@@ -395,9 +405,9 @@ gimp_radio_group_new2 (gboolean        in_frame,
   GSList    *group;
 
   /*  radio button variables  */
-  gchar      *label;
-  gpointer    user_data;
-  GtkWidget **widget_ptr;
+  const gchar *label;
+  gpointer     user_data;
+  GtkWidget  **widget_ptr;
 
   va_list args;
 
@@ -407,7 +417,8 @@ gimp_radio_group_new2 (gboolean        in_frame,
 
   /*  create the radio buttons  */
   va_start (args, initial);
-  label = va_arg (args, gchar*);
+  label = va_arg (args, const gchar *);
+
   while (label)
     {
       user_data  = va_arg (args, gpointer);
@@ -436,7 +447,7 @@ gimp_radio_group_new2 (gboolean        in_frame,
 
       gtk_widget_show (button);
 
-      label = va_arg (args, gchar*);
+      label = va_arg (args, const gchar *);
     }
   va_end (args);
 
@@ -458,23 +469,22 @@ gimp_radio_group_new2 (gboolean        in_frame,
 
 /**
  * gimp_spin_button_new:
- * @adjustment: Returns the spinbutton's #GtkAdjustment.
- * @value: The initial value of the spinbutton.
- * @lower: The lower boundary.
- * @upper: The uppper boundary.
+ * @adjustment:     Returns the spinbutton's #GtkAdjustment.
+ * @value:          The initial value of the spinbutton.
+ * @lower:          The lower boundary.
+ * @upper:          The uppper boundary.
  * @step_increment: The spinbutton's step increment.
  * @page_increment: The spinbutton's page increment (mouse button 2).
- * @page_size: The spinbutton's page size.
- * @climb_rate: The spinbutton's climb rate.
- * @digits: The spinbutton's number of decimal digits.
+ * @page_size:      The spinbutton's page size.
+ * @climb_rate:     The spinbutton's climb rate.
+ * @digits:         The spinbutton's number of decimal digits.
  *
  * This function is a shortcut for gtk_adjustment_new() and a subsequent
  * gtk_spin_button_new() and does some more initialisation stuff like
  * setting a standard minimun horizontal size.
  *
  * Returns: A #GtkSpinbutton and it's #GtkAdjustment.
- *
- */
+ **/
 GtkWidget *
 gimp_spin_button_new (GtkObject **adjustment,  /* return value */
 		      gfloat      value,
@@ -514,26 +524,27 @@ gimp_scale_entry_unconstrained_adjustment_callback (GtkAdjustment *adjustment,
 
 /**
  * gimp_scale_entry_new:
- * @table: The #GtkTable the widgets will be attached to.
- * @column: The column to start with.
- * @row: The row to attach the widgets.
- * @text: The text for the #GtkLabel which will appear left of the #GtkHScale.
- * @scale_usize: The minimum horizontal size of the #GtkHScale.
- * @spinbutton_usize: The minimum horizontal size of the #GtkSpinButton.
- * @value: The initial value.
- * @lower: The lower boundary.
- * @upper: The upper boundary.
- * @step_increment: The step increment.
- * @page_increment: The page increment.
- * @digits: The number of decimal digits.
- * @constrain: #TRUE if the range of possible values of the #GtkSpinButton
- *             should be the same as of the #GtkHScale.
+ * @table:               The #GtkTable the widgets will be attached to.
+ * @column:              The column to start with.
+ * @row:                 The row to attach the widgets.
+ * @text:                The text for the #GtkLabel which will appear
+ *                       left of the #GtkHScale.
+ * @scale_usize:         The minimum horizontal size of the #GtkHScale.
+ * @spinbutton_usize:    The minimum horizontal size of the #GtkSpinButton.
+ * @value:               The initial value.
+ * @lower:               The lower boundary.
+ * @upper:               The upper boundary.
+ * @step_increment:      The step increment.
+ * @page_increment:      The page increment.
+ * @digits:              The number of decimal digits.
+ * @constrain:           #TRUE if the range of possible values of the
+ *                       #GtkSpinButton should be the same as of the #GtkHScale.
  * @unconstrained_lower: The spinbutton's lower boundary
  *                       if @constrain == #FALSE.
  * @unconstrained_upper: The spinbutton's upper boundary
  *                       if @constrain == #FALSE.
- * @tooltip: A tooltip message for the scale and the spinbutton.
- * @help_data: The widgets' help_data (see gimp_help_set_help_data()).
+ * @tooltip:             A tooltip message for the scale and the spinbutton.
+ * @help_data:           The widgets' help_data (see gimp_help_set_help_data()).
  *
  * This function creates a #GtkLabel, a #GtkHScale and a #GtkSpinButton and
  * attaches them to a 3-column #GtkTable.
@@ -542,26 +553,25 @@ gimp_scale_entry_unconstrained_adjustment_callback (GtkAdjustment *adjustment,
  * have to initialize GIMP's help system with gimp_help_init() before using it.
  *
  * Returns: The #GtkSpinButton's #GtkAdjustment.
- *
- */
+ **/
 GtkObject *
-gimp_scale_entry_new (GtkTable *table,
-		      gint      column,
-		      gint      row,
-		      gchar    *text,
-		      gint      scale_usize,
-		      gint      spinbutton_usize,
-		      gfloat    value,
-		      gfloat    lower,
-		      gfloat    upper,
-		      gfloat    step_increment,
-		      gfloat    page_increment,
-		      guint     digits,
-		      gboolean  constrain,
-		      gfloat    unconstrained_lower,
-		      gfloat    unconstrained_upper,
-		      gchar    *tooltip,
-		      gchar    *help_data)
+gimp_scale_entry_new (GtkTable    *table,
+		      gint         column,
+		      gint         row,
+		      const gchar *text,
+		      gint         scale_usize,
+		      gint         spinbutton_usize,
+		      gfloat       value,
+		      gfloat       lower,
+		      gfloat       upper,
+		      gfloat       step_increment,
+		      gfloat       page_increment,
+		      guint        digits,
+		      gboolean     constrain,
+		      gfloat       unconstrained_lower,
+		      gfloat       unconstrained_upper,
+		      const gchar *tooltip,
+		      const gchar *help_data)
 {
   GtkWidget *label;
   GtkWidget *scale;
@@ -655,21 +665,21 @@ gimp_random_seed_toggle_update (GtkWidget *widget,
   toggle_val = (gint *) data;
 
   if (gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (widget)))
-    *toggle_val = (gint) gtk_object_get_data (GTK_OBJECT (widget),
-					      "time_true");
+    *toggle_val = GPOINTER_TO_INT (gtk_object_get_data (GTK_OBJECT (widget),
+							"time_true"));
   else
-    *toggle_val = (gint) gtk_object_get_data (GTK_OBJECT (widget),
-					      "time_false");
+    *toggle_val = GPOINTER_TO_INT (gtk_object_get_data (GTK_OBJECT (widget),
+							"time_false"));
 
   gimp_toggle_button_sensitive_update (GTK_TOGGLE_BUTTON (widget));
 }
 
 /**
  * gimp_random_seed_new:
- * @seed: A pointer to the variable which stores the random seed.
- * @use_time: A pointer to the variable which stores the @use_time
- *            toggle boolean.
- * @time_true: The value to write to @use_time if the toggle button is checked.
+ * @seed:       A pointer to the variable which stores the random seed.
+ * @use_time:   A pointer to the variable which stores the @use_time
+ *              toggle boolean.
+ * @time_true:  The value to write to @use_time if the toggle button is checked.
  * @time_false: The value to write to @use_time if the toggle button is
  *              unchecked.
  *
@@ -679,8 +689,7 @@ gimp_random_seed_toggle_update (GtkWidget *widget,
  *
  * Returns: A #GtkHBox containing a #GtkSpinButton for the random seed and
  *          a #GtkToggleButton for toggling the @use_time behaviour.
- *
- */
+ **/
 GtkWidget *
 gimp_random_seed_new (gint       *seed,
 		      gint       *use_time,
@@ -722,9 +731,9 @@ gimp_random_seed_new (gint       *seed,
                              "randomization"), NULL);
 
   gtk_object_set_data (GTK_OBJECT (button), "time_true",
-		       (gpointer) time_true);
+		       GINT_TO_POINTER (time_true));
   gtk_object_set_data (GTK_OBJECT (button), "time_false",
-		       (gpointer) time_false);
+		       GINT_TO_POINTER (time_false));
 
   gtk_object_set_data (GTK_OBJECT (button), "inverse_sensitive",
 		       spinbutton);
@@ -810,43 +819,43 @@ gimp_coordinates_callback (GtkWidget *widget,
 
 /**
  * gimp_coordinates_new:
- * @unit: The initial unit of the #GimpUnitMenu.
- * @unit_format: The unit format string as passed to gimp_size_entry_new().
- * @menu_show_pixels: #TRUE if the #GimpUnitMenu should contain an item for
- *                    GIMP_UNIT_PIXEL.
- * @menu_show_percent: #TRUE if the #GimpUnitMenu should contain an item for
- *                     GIMP_UNIT_PERCENT.
- * @spinbutton_usize: The horizontal usize of the #GimpSizeEntry's
- *                    #GtkSpinButton's.
- * @update_policy: The update policy for the #GimpSizeEntry.
- * @chainbutton_active: #TRUE if the attached #GimpChainButton should be
- *                      active.
+ * @unit:                   The initial unit of the #GimpUnitMenu.
+ * @unit_format:            The unit format string as passed to
+ *                          gimp_size_entry_new().
+ * @menu_show_pixels:       #TRUE if the #GimpUnitMenu should contain an item for
+ *                          GIMP_UNIT_PIXEL.
+ * @menu_show_percent:      #TRUE if the #GimpUnitMenu should contain an item for
+ *                          GIMP_UNIT_PERCENT.
+ * @spinbutton_usize:       The horizontal usize of the #GimpSizeEntry's
+ *                           #GtkSpinButton's.
+ * @update_policy:          The update policy for the #GimpSizeEntry.
+ * @chainbutton_active:     #TRUE if the attached #GimpChainButton should be
+ *                          active.
  * @chain_constrains_ratio: #TRUE if the chainbutton should constrain the
  *                          fields' aspect ratio. If #FALSE, the values will
  *                          be constrained.
- * @xlabel: The label for the X coordinate.
- * @x: The initial value of the X coordinate.
- * @xres: The horizontal resolution in DPI.
- * @lower_boundary_x: The lower boundary of the X coordinate.
- * @upper_boundary_x: The upper boundary of the X coordinate.
- * @xsize_0: The X value which will be treated as 0%.
- * @xsize_100: The X value which will be treated as 100%.
- * @ylabel: The label for the Y coordinate.
- * @y: The initial value of the Y coordinate.
- * @yres: The vertical resolution in DPI.
- * @lower_boundary_y: The lower boundary of the Y coordinate.
- * @upper_boundary_y: The upper boundary of the Y coordinate.
- * @ysize_0: The Y value which will be treated as 0%.
- * @ysize_100: The Y value which will be treated as 100%.
+ * @xlabel:                 The label for the X coordinate.
+ * @x:                      The initial value of the X coordinate.
+ * @xres:                   The horizontal resolution in DPI.
+ * @lower_boundary_x:       The lower boundary of the X coordinate.
+ * @upper_boundary_x:       The upper boundary of the X coordinate.
+ * @xsize_0:                The X value which will be treated as 0%.
+ * @xsize_100:              The X value which will be treated as 100%.
+ * @ylabel:                 The label for the Y coordinate.
+ * @y:                      The initial value of the Y coordinate.
+ * @yres:                   The vertical resolution in DPI.
+ * @lower_boundary_y:       The lower boundary of the Y coordinate.
+ * @upper_boundary_y:       The upper boundary of the Y coordinate.
+ * @ysize_0:                The Y value which will be treated as 0%.
+ * @ysize_100:              The Y value which will be treated as 100%.
  *
  * Returns: A #GimpSizeEntry with two fields for x/y coordinates/sizes with
  *          a #GimpChainButton attached to constrain either the two fields'
  *          values or the ratio between them.
- *
- */
+ **/
 GtkWidget *
 gimp_coordinates_new (GimpUnit         unit,
-		      gchar           *unit_format,
+		      const gchar     *unit_format,
 		      gboolean         menu_show_pixels,
 		      gboolean         menu_show_percent,
 		      gint             spinbutton_usize,
@@ -855,7 +864,7 @@ gimp_coordinates_new (GimpUnit         unit,
 		      gboolean         chainbutton_active,
 		      gboolean         chain_constrains_ratio,
 
-		      gchar           *xlabel,
+		      const gchar     *xlabel,
 		      gdouble          x,
 		      gdouble          xres,
 		      gdouble          lower_boundary_x,
@@ -863,7 +872,7 @@ gimp_coordinates_new (GimpUnit         unit,
 		      gdouble          xsize_0,   /* % */
 		      gdouble          xsize_100, /* % */
 
-		      gchar           *ylabel,
+		      const gchar     *ylabel,
 		      gdouble          y,
 		      gdouble          yres,
 		      gdouble          lower_boundary_y,
@@ -990,7 +999,7 @@ gimp_mem_size_unit_callback (GtkWidget *widget,
  * @adjustment: The adjustment containing the memsize and it's limits.
  *
  * Returns: A #GtkHBox with a #GtkSpinButton and a #GtkOptionMenu.
- */
+ **/
 GtkWidget *
 gimp_mem_size_entry_new (GtkAdjustment *adjustment)
 {
@@ -1008,7 +1017,7 @@ gimp_mem_size_entry_new (GtkAdjustment *adjustment)
 
   for (i = 0; i < 3; i++)
     {
-      if ( (gint)adjustment->value % (mem_size_unit * 1024) != 0 )
+      if ( (gint) adjustment->value % (mem_size_unit * 1024) != 0 )
 	break;
       mem_size_unit *= 1024;
     }
@@ -1017,7 +1026,7 @@ gimp_mem_size_entry_new (GtkAdjustment *adjustment)
   hbox = gtk_hbox_new (FALSE, 2);
   spinbutton =
     gimp_spin_button_new (&divided_adj, divided_mem_size,
-			  0.0, (4069.0 * 1024 * 1024 - 1), 1.0, 16.0, 0.0,
+			  0.0, (4096.0 * 1024 * 1024 - 1), 1.0, 16.0, 0.0,
 			  1.0, 0.0);
   gtk_signal_connect (GTK_OBJECT (divided_adj), "value_changed",
 		      GTK_SIGNAL_FUNC (gimp_mem_size_entry_callback),
@@ -1057,14 +1066,13 @@ gimp_mem_size_entry_new (GtkAdjustment *adjustment)
 /**
  * gimp_pixmap_button_new:
  * @xpm_data: The XPM data which will be passed to gimp_pixmap_new().
- * @text: An optional text which will appear right of the pixmap.
+ * @text:     An optional text which will appear right of the pixmap.
  *
  * Returns: A #GtkButton with a #GimpPixmap and an optional #GtkLabel.
- *
- */
+ **/
 GtkWidget *
-gimp_pixmap_button_new (gchar **xpm_data,
-			gchar  *text)
+gimp_pixmap_button_new (gchar       **xpm_data,
+			const gchar  *text)
 {
   GtkWidget *button;
   GtkWidget *pixmap;
@@ -1123,8 +1131,7 @@ gimp_pixmap_button_new (gchar **xpm_data,
  * This function can also set the sensitive state according to the toggle
  * button's inverse "active" state by attaching widgets with the
  * "inverse_sensitive" key.
- *
- */
+ **/
 void
 gimp_toggle_button_sensitive_update (GtkToggleButton *toggle_button)
 {
@@ -1155,12 +1162,11 @@ gimp_toggle_button_sensitive_update (GtkToggleButton *toggle_button)
 /**
  * gimp_toggle_button_update:
  * @widget: A #GtkToggleButton.
- * @data: A pointer to a #gint variable which will store the value of
- *        gtk_toggle_button_get_active().
+ * @data:   A pointer to a #gint variable which will store the value of
+ *          gtk_toggle_button_get_active().
  *
  * Note that this function calls gimp_toggle_button_sensitive_update().
- *
- */
+ **/
 void
 gimp_toggle_button_update (GtkWidget *widget,
 			   gpointer   data)
@@ -1180,12 +1186,11 @@ gimp_toggle_button_update (GtkWidget *widget,
 /**
  * gimp_radio_button_update:
  * @widget: A #GtkRadioButton.
- * @data: A pointer to a #gint variable which will store the value of
- *        (#gint) gtk_object_get_user_data().
+ * @data:   A pointer to a #gint variable which will store the value of
+ *          GPOINTER_TO_INT (gtk_object_get_user_data()).
  *
  * Note that this function calls gimp_toggle_button_sensitive_update().
- *
- */
+ **/
 void
 gimp_radio_button_update (GtkWidget *widget,
 			  gpointer   data)
@@ -1196,7 +1201,8 @@ gimp_radio_button_update (GtkWidget *widget,
     {
       toggle_val = (gint *) data;
 
-      *toggle_val = (gint) gtk_object_get_user_data (GTK_OBJECT (widget));
+      *toggle_val =
+	GPOINTER_TO_INT (gtk_object_get_user_data (GTK_OBJECT (widget)));
     }
 
   gimp_toggle_button_sensitive_update (GTK_TOGGLE_BUTTON (widget));
@@ -1205,10 +1211,9 @@ gimp_radio_button_update (GtkWidget *widget,
 /**
  * gimp_menu_item_update:
  * @widget: A #GtkMenuItem.
- * @data: A pointer to a #gint variable which will store the value of
- *        (#gint) gtk_object_get_user_data().
- *
- */
+ * @data:   A pointer to a #gint variable which will store the value of
+ *          GPOINTER_TO_INT (gtk_object_get_user_data()).
+ **/
 void
 gimp_menu_item_update (GtkWidget *widget,
 		       gpointer   data)
@@ -1217,19 +1222,18 @@ gimp_menu_item_update (GtkWidget *widget,
 
   item_val = (gint *) data;
 
-  *item_val = (gint) gtk_object_get_user_data (GTK_OBJECT (widget));
+  *item_val = GPOINTER_TO_INT (gtk_object_get_user_data (GTK_OBJECT (widget)));
 }
 
 /**
  * gimp_int_adjustment_update:
  * @adjustment: A #GtkAdjustment.
- * @data: A pointer to a #gint variable which will store the adjustment's
- *        value.
+ * @data:       A pointer to a #gint variable which will store the
+ *              @adjustment's value.
  *
  * Note that the #GtkAdjustment's value (which is a #gfloat) will be rounded
- * with (#gint) (value + 0.5).
- *
- */
+ * with RINT().
+ **/
 void
 gimp_int_adjustment_update (GtkAdjustment *adjustment,
 			    gpointer       data)
@@ -1237,19 +1241,18 @@ gimp_int_adjustment_update (GtkAdjustment *adjustment,
   gint *val;
 
   val = (gint *) data;
-  *val = (gint) (adjustment->value + 0.5);
+  *val = RINT (adjustment->value);
 }
 
 /**
  * gimp_uint_adjustment_update:
  * @adjustment: A #GtkAdjustment.
- * @data: A pointer to a #guint variable which will store the adjustment's
- *        value.
+ * @data:       A pointer to a #guint variable which will store the
+ *              @adjustment's value.
  *
  * Note that the #GtkAdjustment's value (which is a #gfloat) will be rounded
  * with (#guint) (value + 0.5).
- *
- */
+ **/
 void
 gimp_uint_adjustment_update (GtkAdjustment *adjustment,
 			     gpointer       data)
@@ -1263,10 +1266,9 @@ gimp_uint_adjustment_update (GtkAdjustment *adjustment,
 /**
  * gimp_float_adjustment_update:
  * @adjustment: A #GtkAdjustment.
- * @data: A pointer to a #gfloat varaiable which willl store the adjustment's
- *        value.
- *
- */
+ * @data:       A pointer to a #gfloat varaiable which willl store the
+ *              @adjustment's value.
+ **/
 void
 gimp_float_adjustment_update (GtkAdjustment *adjustment,
 			      gpointer       data)
@@ -1280,10 +1282,9 @@ gimp_float_adjustment_update (GtkAdjustment *adjustment,
 /**
  * gimp_double_adjustment_update:
  * @adjustment: A #GtkAdjustment.
- * @data: A pointer to a #gdouble variable which will store the adjustment's
- *        value.
- *
- */
+ * @data:       A pointer to a #gdouble variable which will store the
+ *              @adjustment's value.
+ **/
 void
 gimp_double_adjustment_update (GtkAdjustment *adjustment,
 			       gpointer       data)
@@ -1297,8 +1298,8 @@ gimp_double_adjustment_update (GtkAdjustment *adjustment,
 /**
  * gimp_unit_menu_update:
  * @widget: A #GimpUnitMenu.
- * @data: A pointer to a #GimpUnit variable which will store the unit menu's
- *        value.
+ * @data:   A pointer to a #GimpUnit variable which will store the unit menu's
+ *          value.
  *
  * This callback can set the number of decimal digits of an arbitrary number
  * of #GtkSpinButton's. To use this functionality, attach the spinbuttons
@@ -1307,8 +1308,7 @@ gimp_double_adjustment_update (GtkAdjustment *adjustment,
  *
  * See gimp_toggle_button_sensitive_update() for a description of how
  * to set up the list.
- *
- */
+ **/
 void
 gimp_unit_menu_update (GtkWidget *widget,
 		       gpointer   data)
@@ -1339,31 +1339,30 @@ gimp_unit_menu_update (GtkWidget *widget,
 
 /**
  * gimp_table_attach_aligned:
- * @table: The #GtkTable the widgets will be attached to.
- * @column: The column to start with.
- * @row: The row to attach the eidgets.
+ * @table:      The #GtkTable the widgets will be attached to.
+ * @column:     The column to start with.
+ * @row:        The row to attach the eidgets.
  * @label_text: The text for the #GtkLabel which will be attached left of the
  *              widget.
- * @xalign: The horizontal alignment of the #GtkLabel.
- * @yalign: The vertival alignment of the #GtkLabel.
- * @widget: The #GtkWidget to attach right of the label.
- * @colspan: The number of columns the widget will use.
+ * @xalign:     The horizontal alignment of the #GtkLabel.
+ * @yalign:     The vertival alignment of the #GtkLabel.
+ * @widget:     The #GtkWidget to attach right of the label.
+ * @colspan:    The number of columns the widget will use.
  * @left_align: #TRUE if the widget should be left-aligned.
  *
  * Note that the @label_text can be #NULL and that the widget will be attached
  * starting at (@column + 1) in this case, too.
- *
- */
+ **/
 void
-gimp_table_attach_aligned (GtkTable  *table,
-			   gint       column,
-			   gint       row,
-			   gchar     *label_text,
-			   gfloat     xalign,
-			   gfloat     yalign,
-			   GtkWidget *widget,
-			   gint       colspan,
-			   gboolean   left_align)
+gimp_table_attach_aligned (GtkTable    *table,
+			   gint         column,
+			   gint         row,
+			   const gchar *label_text,
+			   gfloat       xalign,
+			   gfloat       yalign,
+			   GtkWidget   *widget,
+			   gint         colspan,
+			   gboolean     left_align)
 {
   if (label_text)
     {
