@@ -2,41 +2,162 @@
 /* Compute a preview image and preview wireframe */
 /*************************************************/
 
+#include <gtk/gtk.h>
+
+#include <gck/gck.h>
+
+#include <libgimp/gimp.h>
+
+#include "arcball.h"
+#include "mapobject_main.h"
+#include "mapobject_ui.h"
+#include "mapobject_image.h"
+#include "mapobject_apply.h"
+#include "mapobject_shade.h"
 #include "mapobject_preview.h"
 
 line    linetab[WIRESIZE*2+8];
 gdouble mat[3][4];
 
-gint lightx,lighty;
+gint       lightx,lighty;
 BackBuffer backbuf={0,0,0,0,NULL};
 
 /* Protos */
 /* ====== */
 
-void update_light       (gint xpos,gint ypos);
-void draw_light_marker  (gint xpos,gint ypos);
-void clear_light_marker (void);
+static void draw_light_marker  (gint        xpos,
+				gint        ypos);
+static void clear_light_marker (void);
 
-gint draw_line (gint n, gint startx,gint starty,gint pw,gint ph,
-                gdouble cx1, gdouble cy1, gdouble cx2, gdouble cy2,
-                GckVector3 a,GckVector3 b);
+static gint draw_line          (gint        n,
+				gint        startx,
+				gint        starty,
+				gint        pw,
+				gint        ph,
+				gdouble     cx1,
+				gdouble     cy1,
+				gdouble     cx2,
+				gdouble     cy2,
+				GimpVector3 a,
+				GimpVector3 b);
 
-void draw_wireframe_plane    (gint startx,gint starty,gint pw,gint ph);
-void draw_wireframe_sphere   (gint startx,gint starty,gint pw,gint ph);
-void draw_wireframe_box      (gint startx,gint starty,gint pw,gint ph);
-void draw_wireframe_cylinder (gint startx,gint starty,gint pw,gint ph);
+static void draw_wireframe_plane    (gint startx,
+				     gint starty,
+				     gint pw,
+				     gint ph);
+static void draw_wireframe_sphere   (gint startx,
+				     gint starty,
+				     gint pw,
+				     gint ph);
+static void draw_wireframe_box      (gint startx,
+				     gint starty,
+				     gint pw,
+				     gint ph);
+static void draw_wireframe_cylinder (gint startx,
+				     gint starty,
+				     gint pw,
+				     gint ph);
 
-void clear_wireframe (void);
+/*************************************************/
+/* Quick and dirty (and slow) line clip routine. */
+/* The function returns FALSE if the line isn't  */
+/* visible according to the limits given.        */
+/*************************************************/
+
+static gboolean
+clip_line (gdouble *x1,
+	   gdouble *y1,
+	   gdouble *x2,
+	   gdouble *y2,
+	   gdouble  minx,
+	   gdouble  miny,
+	   gdouble  maxx,
+	   gdouble  maxy)
+{
+  gdouble tmp;
+
+  g_assert (x1!=NULL);
+  g_assert (y1!=NULL);
+  g_assert (x2!=NULL);
+  g_assert (y2!=NULL);
+
+  /* First, check if line is visible at all */
+  /* ====================================== */
+
+  if (*x1<minx && *x2<minx) return(FALSE);
+  if (*x1>maxx && *x2>maxx) return(FALSE);
+  if (*y1<miny && *y2<miny) return(FALSE);
+  if (*y1>maxy && *y2>maxy) return(FALSE);
+
+  /* Check for intersection with the four edges. Sort on x first. */
+  /* ============================================================ */
+
+  if (*x2<*x1)
+    {
+      tmp=*x1;
+      *x1=*x2;
+      *x2=tmp;
+      tmp=*y1;
+      *y1=*y2;
+      *y2=tmp;
+    }
+
+  if (*x1<minx)
+    {
+      if (*y1<*y2) *y1=*y1+(minx-*x1)*((*y2-*y1)/(*x2-*x1));
+      else         *y1=*y1-(minx-*x1)*((*y1-*y2)/(*x2-*x1));
+      *x1=minx; 
+    }
+
+  if (*x2>maxx)
+    {
+      if (*y1<*y2) *y2=*y2-(*x2-maxx)*((*y2-*y1)/(*x2-*x1));
+      else         *y2=*y2+(*x2-maxx)*((*y1-*y2)/(*x2-*x1));
+      *x2=maxx;
+    }
+
+  if (*y1<miny)
+    {
+      *x1=*x1+(miny-*y1)*((*x2-*x1)/(*y2-*y1));
+      *y1=miny;
+    }
+  
+  if (*y2<miny)
+    {
+      *x2=*x2-(miny-*y2)*((*x2-*x1)/(*y1-*y2));
+      *y2=miny;
+    }
+
+  if (*y1>maxy)
+    {
+      *x1=*x1+(*y1-maxy)*((*x2-*x1)/(*y1-*y2));
+      *y1=maxy;
+    }
+    
+  if (*y2>maxy)
+    {
+      *x2=*x2-(*y2-maxy)*((*x2-*x1)/(*y2-*y1));
+      *y2=maxy;
+    }
+
+  return TRUE;
+}
 
 /**************************************************************/
 /* Computes a preview of the rectangle starting at (x,y) with */
 /* dimensions (w,h), placing the result in preview_RGB_data.  */ 
 /**************************************************************/
 
-void compute_preview(gint x,gint y,gint w,gint h,gint pw,gint ph)
+void
+compute_preview (gint x,
+		 gint y,
+		 gint w,
+		 gint h,
+		 gint pw,
+		 gint ph)
 {
   gdouble xpostab[PREVIEW_WIDTH],ypostab[PREVIEW_HEIGHT],realw,realh;
-  GckVector3 p1,p2;
+  GimpVector3 p1,p2;
   GckRGB color,lightcheck,darkcheck,temp;
   guchar r,g,b;
   gint xcnt,ycnt,f1,f2;
@@ -75,7 +196,7 @@ void compute_preview(gint x,gint y,gint w,gint h,gint pw,gint ph)
 
   gck_rgb_set(&lightcheck,0.75,0.75,0.75);
   gck_rgb_set(&darkcheck, 0.50,0.50,0.50);
-  gck_vector3_set(&p2,-1.0,-1.0,0.0);
+  gimp_vector3_set(&p2,-1.0,-1.0,0.0);
 
   for (ycnt=0;ycnt<ph;ycnt++)
     {
@@ -128,7 +249,7 @@ void compute_preview(gint x,gint y,gint w,gint h,gint pw,gint ph)
   /* Convert to visual type */
   /* ====================== */
 
-  gck_rgb_to_gdkimage(appwin->visinfo,preview_rgb_data,image,pw,ph);
+  gck_rgb_to_gdkimage(visinfo,preview_rgb_data,image,pw,ph);
 }
 
 /*************************************************/
@@ -136,7 +257,9 @@ void compute_preview(gint x,gint y,gint w,gint h,gint pw,gint ph)
 /* light marker. Return TRUE if so, FALSE if not */
 /*************************************************/
 
-gint check_light_hit(gint xpos,gint ypos)
+gint
+check_light_hit (gint xpos,
+		 gint ypos)
 {
   gdouble dx,dy,r;
   
@@ -158,10 +281,12 @@ gint check_light_hit(gint xpos,gint ypos)
 /* Draw a marker to show light position */
 /****************************************/
 
-void draw_light_marker(gint xpos,gint ypos)
+static void
+draw_light_marker (gint xpos,
+		   gint ypos)
 {
-  gck_gc_set_foreground(appwin->visinfo,gc,0,50,255);
-  gck_gc_set_background(appwin->visinfo,gc,0,0,0);
+  gck_gc_set_foreground(visinfo,gc,0,50,255);
+  gck_gc_set_background(visinfo,gc,0,0,0);
 
   gdk_gc_set_function(gc,GDK_COPY);
 
@@ -196,15 +321,16 @@ void draw_light_marker(gint xpos,gint ypos)
     }
 }
 
-void clear_light_marker()
+static void
+clear_light_marker (void)
 {
   /* Restore background if it has been saved */
   /* ======================================= */
   
   if (backbuf.image!=NULL)
     {
-      gck_gc_set_foreground(appwin->visinfo,gc,255,255,255);
-      gck_gc_set_background(appwin->visinfo,gc,0,0,0);
+      gck_gc_set_foreground(visinfo,gc,255,255,255);
+      gck_gc_set_background(visinfo,gc,0,0,0);
 
       gdk_gc_set_function(gc,GDK_COPY);
       gdk_draw_image(previewarea->window,gc,backbuf.image,0,0,backbuf.x,backbuf.y,
@@ -214,14 +340,18 @@ void clear_light_marker()
     }
 }
 
-void draw_lights(gint startx,gint starty,gint pw,gint ph)
+static void
+draw_lights (gint startx,
+	     gint starty,
+	     gint pw,
+	     gint ph)
 {
   gdouble dxpos,dypos;
   gint xpos,ypos;
 
   clear_light_marker();
  
-  gck_3d_to_2d(startx,starty,pw,ph,&dxpos,&dypos,&mapvals.viewpoint,
+  gimp_vector_3d_to_2d(startx,starty,pw,ph,&dxpos,&dypos,&mapvals.viewpoint,
     &mapvals.lightsource.position);
   xpos=(gint)(dxpos+0.5);
   ypos=(gint)(dypos+0.5);
@@ -234,7 +364,9 @@ void draw_lights(gint startx,gint starty,gint pw,gint ph)
 /* Update light position given new screen coords */
 /*************************************************/
 
-void update_light(gint xpos,gint ypos)
+void
+update_light (gint xpos,
+	      gint ypos)
 {
   gint startx,starty,pw,ph;
 
@@ -243,7 +375,7 @@ void update_light(gint xpos,gint ypos)
   startx=(PREVIEW_WIDTH-pw)>>1;
   starty=(PREVIEW_HEIGHT-ph)>>1;
   
-  gck_2d_to_3d(startx,starty,pw,ph,xpos,ypos,&mapvals.viewpoint,&mapvals.lightsource.position);
+  gimp_vector_2d_to_3d(startx,starty,pw,ph,xpos,ypos,&mapvals.viewpoint,&mapvals.lightsource.position);
   draw_lights(startx,starty,pw,ph);
 }
 
@@ -251,46 +383,59 @@ void update_light(gint xpos,gint ypos)
 /* Draw preview image. if DoCompute is TRUE then recompute image. */
 /******************************************************************/
 
-void draw_preview_image(gint docompute)
+void
+draw_preview_image (gint docompute)
 {
-  gint startx,starty,pw,ph;
-  
-  gck_gc_set_foreground(appwin->visinfo,gc,255,255,255);
-  gck_gc_set_background(appwin->visinfo,gc,0,0,0);
+  gint startx, starty, pw, ph;
 
-  gdk_gc_set_function(gc,GDK_COPY);
-  linetab[0].x1=-1;
+  gck_gc_set_foreground (visinfo, gc, 255, 255, 255);
+  gck_gc_set_background (visinfo, gc,   0,   0,   0);
 
-  pw=PREVIEW_WIDTH >> mapvals.preview_zoom_factor;
-  ph=PREVIEW_HEIGHT >> mapvals.preview_zoom_factor;
-  startx=(PREVIEW_WIDTH-pw)>>1;
-  starty=(PREVIEW_HEIGHT-ph)>>1;
+  gdk_gc_set_function (gc, GDK_COPY);
+  linetab[0].x1 = -1;
 
-  if (docompute==TRUE)
+  pw = PREVIEW_WIDTH >> mapvals.preview_zoom_factor;
+  ph = PREVIEW_HEIGHT >> mapvals.preview_zoom_factor;
+  startx = (PREVIEW_WIDTH - pw) >> 1;
+  starty = (PREVIEW_HEIGHT - ph) >> 1;
+
+  if (docompute == TRUE)
     {
-      gck_cursor_set(previewarea->window,GDK_WATCH);
-      compute_preview(0,0,width-1,height-1,pw,ph);
-      gck_cursor_set(previewarea->window,GDK_HAND2);
-      clear_light_marker();
+      GdkCursor *newcursor;
+
+      newcursor = gdk_cursor_new (GDK_WATCH);
+      gdk_window_set_cursor(previewarea->window, newcursor);
+      gdk_cursor_destroy (newcursor);
+      gdk_flush();
+
+      compute_preview (0, 0, width - 1, height - 1, pw, ph);
+
+      newcursor = gdk_cursor_new (GDK_HAND2);
+      gdk_window_set_cursor(previewarea->window, newcursor);
+      gdk_cursor_destroy (newcursor);
+      gdk_flush();
+
+      clear_light_marker ();
     }
 
-  if (pw!=PREVIEW_WIDTH)
-    gdk_window_clear(previewarea->window);
-  
-  gdk_draw_image(previewarea->window,gc,image,0,0,startx,starty,pw,ph);
-  draw_lights(startx,starty,pw,ph);
+  if (pw != PREVIEW_WIDTH)
+    gdk_window_clear (previewarea->window);
+
+  gdk_draw_image (previewarea->window, gc, image, 0, 0, startx, starty, pw, ph);
+  draw_lights (startx, starty, pw, ph);
 }
 
 /**************************/
 /* Draw preview wireframe */
 /**************************/
 
-void draw_preview_wireframe(void)
+void
+draw_preview_wireframe (void)
 {
   gint startx,starty,pw,ph;
 
-  gck_gc_set_foreground(appwin->visinfo,gc,255,255,255);
-  gck_gc_set_background(appwin->visinfo,gc,0,0,0);
+  gck_gc_set_foreground(visinfo,gc,255,255,255);
+  gck_gc_set_background(visinfo,gc,0,0,0);
 
   gdk_gc_set_function(gc,GDK_INVERT);
 
@@ -307,55 +452,63 @@ void draw_preview_wireframe(void)
 /* Draw a wireframe preview */
 /****************************/
 
-void draw_wireframe(gint startx,gint starty,gint pw,gint ph)
+void
+draw_wireframe (gint startx,
+		gint starty,
+		gint pw,
+		gint ph)
 {
   switch (mapvals.maptype)
     {
-      case MAP_PLANE:
-        draw_wireframe_plane(startx,starty,pw,ph);
-        break;
-      case MAP_SPHERE:
-        draw_wireframe_sphere(startx,starty,pw,ph);
-        break;
-      case MAP_BOX:
-        draw_wireframe_box(startx,starty,pw,ph);
-        break;
-      case MAP_CYLINDER:
-        draw_wireframe_cylinder(startx,starty,pw,ph);
-        break;
+    case MAP_PLANE:
+      draw_wireframe_plane(startx,starty,pw,ph);
+      break;
+    case MAP_SPHERE:
+      draw_wireframe_sphere(startx,starty,pw,ph);
+      break;
+    case MAP_BOX:
+      draw_wireframe_box(startx,starty,pw,ph);
+      break;
+    case MAP_CYLINDER:
+      draw_wireframe_cylinder(startx,starty,pw,ph);
+      break;
     }
 }
 
-void draw_wireframe_plane(gint startx,gint starty,gint pw,gint ph)
+static void
+draw_wireframe_plane (gint startx,
+		      gint starty,
+		      gint pw,
+		      gint ph)
 {
-  GckVector3 v1,v2,a,b,c,d,dir1,dir2;
+  GimpVector3 v1,v2,a,b,c,d,dir1,dir2;
   gint cnt,n=0;
   gdouble x1,y1,x2,y2,cx1,cy1,cx2,cy2,fac;
   
   /* Find rotated box corners */
   /* ======================== */
 
-  gck_vector3_set(&v1,0.5,0.0,0.0);
-  gck_vector3_set(&v2,0.0,0.5,0.0);
+  gimp_vector3_set(&v1,0.5,0.0,0.0);
+  gimp_vector3_set(&v2,0.0,0.5,0.0);
 
-  gck_vector3_rotate(&v1,gck_deg_to_rad(mapvals.alpha),
-    gck_deg_to_rad(mapvals.beta),gck_deg_to_rad(mapvals.gamma));
-  gck_vector3_rotate(&v2,gck_deg_to_rad(mapvals.alpha),
-    gck_deg_to_rad(mapvals.beta),gck_deg_to_rad(mapvals.gamma));
+  gimp_vector3_rotate(&v1,gimp_deg_to_rad(mapvals.alpha),
+    gimp_deg_to_rad(mapvals.beta),gimp_deg_to_rad(mapvals.gamma));
+  gimp_vector3_rotate(&v2,gimp_deg_to_rad(mapvals.alpha),
+    gimp_deg_to_rad(mapvals.beta),gimp_deg_to_rad(mapvals.gamma));
 
-  dir1=v1; gck_vector3_normalize(&dir1);
-  dir2=v2; gck_vector3_normalize(&dir2);
+  dir1=v1; gimp_vector3_normalize(&dir1);
+  dir2=v2; gimp_vector3_normalize(&dir2);
 
   fac=1.0/(gdouble)WIRESIZE;
   
-  gck_vector3_mul(&dir1,fac);
-  gck_vector3_mul(&dir2,fac);
+  gimp_vector3_mul(&dir1,fac);
+  gimp_vector3_mul(&dir2,fac);
   
-  gck_vector3_add(&a,&mapvals.position,&v1);
-  gck_vector3_sub(&b,&a,&v2);
-  gck_vector3_add(&a,&a,&v2);
-  gck_vector3_sub(&d,&mapvals.position,&v1);
-  gck_vector3_sub(&d,&d,&v2);
+  gimp_vector3_add(&a,&mapvals.position,&v1);
+  gimp_vector3_sub(&b,&a,&v2);
+  gimp_vector3_add(&a,&a,&v2);
+  gimp_vector3_sub(&d,&mapvals.position,&v1);
+  gimp_vector3_sub(&d,&d,&v2);
 
   c=b;
 
@@ -366,10 +519,10 @@ void draw_wireframe_plane(gint startx,gint starty,gint pw,gint ph)
 
   for (cnt=0;cnt<=WIRESIZE;cnt++)
     {
-      gck_3d_to_2d(startx,starty,pw,ph,&x1,&y1,&mapvals.viewpoint,&a);
-      gck_3d_to_2d(startx,starty,pw,ph,&x2,&y2,&mapvals.viewpoint,&b);
+      gimp_vector_3d_to_2d(startx,starty,pw,ph,&x1,&y1,&mapvals.viewpoint,&a);
+      gimp_vector_3d_to_2d(startx,starty,pw,ph,&x2,&y2,&mapvals.viewpoint,&b);
 
-      if (gck_clip_line(&x1,&y1,&x2,&y2,cx1,cy1,cx2,cy2)==TRUE)
+      if (clip_line(&x1,&y1,&x2,&y2,cx1,cy1,cx2,cy2)==TRUE)
         {
           linetab[n].x1=(gint)(x1+0.5);
           linetab[n].y1=(gint)(y1+0.5);
@@ -382,10 +535,10 @@ void draw_wireframe_plane(gint startx,gint starty,gint pw,gint ph)
           n++;
         }
 
-      gck_3d_to_2d(startx,starty,pw,ph,&x1,&y1,&mapvals.viewpoint,&c);
-      gck_3d_to_2d(startx,starty,pw,ph,&x2,&y2,&mapvals.viewpoint,&d);
+      gimp_vector_3d_to_2d(startx,starty,pw,ph,&x1,&y1,&mapvals.viewpoint,&c);
+      gimp_vector_3d_to_2d(startx,starty,pw,ph,&x2,&y2,&mapvals.viewpoint,&d);
 
-      if (gck_clip_line(&x1,&y1,&x2,&y2,cx1,cy1,cx2,cy2)==TRUE)
+      if (clip_line(&x1,&y1,&x2,&y2,cx1,cy1,cx2,cy2)==TRUE)
         {
           linetab[n].x1=(gint)(x1+0.5);
           linetab[n].y1=(gint)(y1+0.5);
@@ -398,10 +551,10 @@ void draw_wireframe_plane(gint startx,gint starty,gint pw,gint ph)
           n++;
         }
         
-      gck_vector3_sub(&a,&a,&dir1);
-      gck_vector3_sub(&b,&b,&dir1);
-      gck_vector3_add(&c,&c,&dir2);
-      gck_vector3_add(&d,&d,&dir2);
+      gimp_vector3_sub(&a,&a,&dir1);
+      gimp_vector3_sub(&b,&b,&dir1);
+      gimp_vector3_add(&c,&c,&dir2);
+      gimp_vector3_add(&d,&d,&dir2);
     }
 
   /* Mark end of lines */
@@ -410,25 +563,29 @@ void draw_wireframe_plane(gint startx,gint starty,gint pw,gint ph)
   linetab[n].x1=-1;
 }
 
-void draw_wireframe_sphere(gint startx,gint starty,gint pw,gint ph)
+static void
+draw_wireframe_sphere (gint startx,
+		       gint starty,
+		       gint pw,
+		       gint ph)
 {
-  GckVector3 p[2*(WIRESIZE+5)];
+  GimpVector3 p[2*(WIRESIZE+5)];
   gint cnt,cnt2,n=0;
   gdouble x1,y1,x2,y2,twopifac,cx1,cy1,cx2,cy2;
   
   /* Compute wireframe points */
   /* ======================== */
 
-  twopifac=(2.0*M_PI)/WIRESIZE;
+  twopifac=(2.0*G_PI)/WIRESIZE;
   
   for (cnt=0;cnt<WIRESIZE;cnt++)
     {
       p[cnt].x=mapvals.radius*cos((gdouble)cnt*twopifac);
       p[cnt].y=0.0;
       p[cnt].z=mapvals.radius*sin((gdouble)cnt*twopifac);
-      gck_vector3_rotate(&p[cnt],gck_deg_to_rad(mapvals.alpha),
-        gck_deg_to_rad(mapvals.beta),gck_deg_to_rad(mapvals.gamma));
-      gck_vector3_add(&p[cnt],&p[cnt],&mapvals.position);
+      gimp_vector3_rotate(&p[cnt],gimp_deg_to_rad(mapvals.alpha),
+        gimp_deg_to_rad(mapvals.beta),gimp_deg_to_rad(mapvals.gamma));
+      gimp_vector3_add(&p[cnt],&p[cnt],&mapvals.position);
     }
   p[cnt]=p[0];
   for (cnt=WIRESIZE+1;cnt<2*WIRESIZE+1;cnt++)
@@ -436,9 +593,9 @@ void draw_wireframe_sphere(gint startx,gint starty,gint pw,gint ph)
       p[cnt].x=mapvals.radius*cos((gdouble)(cnt-(WIRESIZE+1))*twopifac);
       p[cnt].y=mapvals.radius*sin((gdouble)(cnt-(WIRESIZE+1))*twopifac);
       p[cnt].z=0.0;
-      gck_vector3_rotate(&p[cnt],gck_deg_to_rad(mapvals.alpha),
-        gck_deg_to_rad(mapvals.beta),gck_deg_to_rad(mapvals.gamma));
-      gck_vector3_add(&p[cnt],&p[cnt],&mapvals.position);
+      gimp_vector3_rotate(&p[cnt],gimp_deg_to_rad(mapvals.alpha),
+        gimp_deg_to_rad(mapvals.beta),gimp_deg_to_rad(mapvals.gamma));
+      gimp_vector3_add(&p[cnt],&p[cnt],&mapvals.position);
     }
   p[cnt]=p[WIRESIZE+1];
   cnt++;
@@ -447,23 +604,23 @@ void draw_wireframe_sphere(gint startx,gint starty,gint pw,gint ph)
   /* Find rotated axis */
   /* ================= */
 
-  gck_vector3_set(&p[cnt],0.0,-0.35,0.0);
-  gck_vector3_rotate(&p[cnt],gck_deg_to_rad(mapvals.alpha),
-    gck_deg_to_rad(mapvals.beta),gck_deg_to_rad(mapvals.gamma));
+  gimp_vector3_set(&p[cnt],0.0,-0.35,0.0);
+  gimp_vector3_rotate(&p[cnt],gimp_deg_to_rad(mapvals.alpha),
+    gimp_deg_to_rad(mapvals.beta),gimp_deg_to_rad(mapvals.gamma));
   p[cnt+1]=mapvals.position;
 
-  gck_vector3_set(&p[cnt+2],0.0,0.0,-0.35);
-  gck_vector3_rotate(&p[cnt+2],gck_deg_to_rad(mapvals.alpha),
-    gck_deg_to_rad(mapvals.beta),gck_deg_to_rad(mapvals.gamma));
+  gimp_vector3_set(&p[cnt+2],0.0,0.0,-0.35);
+  gimp_vector3_rotate(&p[cnt+2],gimp_deg_to_rad(mapvals.alpha),
+    gimp_deg_to_rad(mapvals.beta),gimp_deg_to_rad(mapvals.gamma));
   p[cnt+3]=mapvals.position;
 
   p[cnt+4]=p[cnt];
-  gck_vector3_mul(&p[cnt+4],-1.0);
+  gimp_vector3_mul(&p[cnt+4],-1.0);
   p[cnt+5]=p[cnt+1];
 
-  gck_vector3_add(&p[cnt],&p[cnt],&mapvals.position);
-  gck_vector3_add(&p[cnt+2],&p[cnt+2],&mapvals.position);
-  gck_vector3_add(&p[cnt+4],&p[cnt+4],&mapvals.position);
+  gimp_vector3_add(&p[cnt],&p[cnt],&mapvals.position);
+  gimp_vector3_add(&p[cnt+2],&p[cnt+2],&mapvals.position);
+  gimp_vector3_add(&p[cnt+4],&p[cnt+4],&mapvals.position);
 
   /* Draw the circles (equator and zero meridian) */
   /* ============================================ */
@@ -477,10 +634,10 @@ void draw_wireframe_sphere(gint startx,gint starty,gint pw,gint ph)
     {
       if (p[cnt].z>mapvals.position.z && p[cnt+1].z>mapvals.position.z)
         {
-          gck_3d_to_2d(startx,starty,pw,ph,&x1,&y1,&mapvals.viewpoint,&p[cnt]);
-          gck_3d_to_2d(startx,starty,pw,ph,&x2,&y2,&mapvals.viewpoint,&p[cnt+1]);
+          gimp_vector_3d_to_2d(startx,starty,pw,ph,&x1,&y1,&mapvals.viewpoint,&p[cnt]);
+          gimp_vector_3d_to_2d(startx,starty,pw,ph,&x2,&y2,&mapvals.viewpoint,&p[cnt+1]);
  
-          if (gck_clip_line(&x1,&y1,&x2,&y2,cx1,cy1,cx2,cy2)==TRUE)
+          if (clip_line(&x1,&y1,&x2,&y2,cx1,cy1,cx2,cy2)==TRUE)
             {
               linetab[n].x1=(gint)(x1+0.5);
               linetab[n].y1=(gint)(y1+0.5);
@@ -500,10 +657,10 @@ void draw_wireframe_sphere(gint startx,gint starty,gint pw,gint ph)
 
   for (cnt=0;cnt<3;cnt++)
     {
-      gck_3d_to_2d(startx,starty,pw,ph,&x1,&y1,&mapvals.viewpoint,&p[cnt2]);
-      gck_3d_to_2d(startx,starty,pw,ph,&x2,&y2,&mapvals.viewpoint,&p[cnt2+1]);
+      gimp_vector_3d_to_2d(startx,starty,pw,ph,&x1,&y1,&mapvals.viewpoint,&p[cnt2]);
+      gimp_vector_3d_to_2d(startx,starty,pw,ph,&x2,&y2,&mapvals.viewpoint,&p[cnt2+1]);
 
-      if (gck_clip_line(&x1,&y1,&x2,&y2,cx1,cy1,cx2,cy2)==TRUE)
+      if (clip_line(&x1,&y1,&x2,&y2,cx1,cy1,cx2,cy2)==TRUE)
         {
           linetab[n].x1=(gint)(x1+0.5);
           linetab[n].y1=(gint)(y1+0.5);
@@ -533,17 +690,26 @@ void draw_wireframe_sphere(gint startx,gint starty,gint pw,gint ph)
   linetab[n].x1=-1;
 }
 
-gint draw_line(gint n, gint startx,gint starty,gint pw,gint ph,
-               gdouble cx1, gdouble cy1, gdouble cx2, gdouble cy2,
-               GckVector3 a,GckVector3 b)
+static gint
+draw_line (gint        n,
+	   gint        startx,
+	   gint        starty,
+	   gint        pw,
+	   gint        ph,
+	   gdouble     cx1,
+	   gdouble     cy1,
+	   gdouble     cx2,
+	   gdouble     cy2,
+	   GimpVector3 a,
+	   GimpVector3 b)
 {
   gdouble x1,y1,x2,y2;
   gint i = n;
   
-  gck_3d_to_2d(startx,starty,pw,ph,&x1,&y1,&mapvals.viewpoint,&a);
-  gck_3d_to_2d(startx,starty,pw,ph,&x2,&y2,&mapvals.viewpoint,&b);
+  gimp_vector_3d_to_2d(startx,starty,pw,ph,&x1,&y1,&mapvals.viewpoint,&a);
+  gimp_vector_3d_to_2d(startx,starty,pw,ph,&x2,&y2,&mapvals.viewpoint,&b);
  
-  if (gck_clip_line(&x1,&y1,&x2,&y2,cx1,cy1,cx2,cy2)==TRUE)
+  if (clip_line(&x1,&y1,&x2,&y2,cx1,cy1,cx2,cy2)==TRUE)
     {
       linetab[i].x1=(gint)(x1+0.5);
       linetab[i].y1=(gint)(y1+0.5);
@@ -561,9 +727,13 @@ gint draw_line(gint n, gint startx,gint starty,gint pw,gint ph,
   return(i);
 }
 
-void draw_wireframe_box(gint startx,gint starty,gint pw,gint ph)
+static void
+draw_wireframe_box (gint startx,
+		    gint starty,
+		    gint pw,
+		    gint ph)
 {
-  GckVector3 p[8], tmp, scale;
+  GimpVector3 p[8], tmp, scale;
   gint n=0,i;
   gdouble cx1,cy1,cx2,cy2;
   
@@ -573,17 +743,17 @@ void draw_wireframe_box(gint startx,gint starty,gint pw,gint ph)
   init_compute();
 
   scale = mapvals.scale;
-  gck_vector3_mul(&scale,0.5);
+  gimp_vector3_mul(&scale,0.5);
 
-  gck_vector3_set(&p[0], -scale.x, -scale.y, scale.z);
-  gck_vector3_set(&p[1],  scale.x, -scale.y, scale.z);
-  gck_vector3_set(&p[2],  scale.x,  scale.y, scale.z);
-  gck_vector3_set(&p[3], -scale.x,  scale.y, scale.z);
+  gimp_vector3_set(&p[0], -scale.x, -scale.y, scale.z);
+  gimp_vector3_set(&p[1],  scale.x, -scale.y, scale.z);
+  gimp_vector3_set(&p[2],  scale.x,  scale.y, scale.z);
+  gimp_vector3_set(&p[3], -scale.x,  scale.y, scale.z);
 
-  gck_vector3_set(&p[4], -scale.x, -scale.y, -scale.z);
-  gck_vector3_set(&p[5],  scale.x, -scale.y, -scale.z);
-  gck_vector3_set(&p[6],  scale.x,  scale.y, -scale.z);
-  gck_vector3_set(&p[7], -scale.x,  scale.y, -scale.z);
+  gimp_vector3_set(&p[4], -scale.x, -scale.y, -scale.z);
+  gimp_vector3_set(&p[5],  scale.x, -scale.y, -scale.z);
+  gimp_vector3_set(&p[6],  scale.x,  scale.y, -scale.z);
+  gimp_vector3_set(&p[7], -scale.x,  scale.y, -scale.z);
 
   /* Rotate and translate points */
   /* =========================== */
@@ -591,7 +761,7 @@ void draw_wireframe_box(gint startx,gint starty,gint pw,gint ph)
   for (i=0;i<8;i++)
     {
       vecmulmat(&tmp,&p[i],rotmat);
-      gck_vector3_add(&p[i],&tmp,&mapvals.position);
+      gimp_vector3_add(&p[i],&tmp,&mapvals.position);
     }
 
   /* Draw the box */
@@ -623,9 +793,13 @@ void draw_wireframe_box(gint startx,gint starty,gint pw,gint ph)
   linetab[n].x1=-1;
 }
 
-void draw_wireframe_cylinder(gint startx,gint starty,gint pw,gint ph)
+static void
+draw_wireframe_cylinder (gint startx,
+			 gint starty,
+			 gint pw,
+			 gint ph)
 {
-  GckVector3 p[2*8], a, axis, scale;
+  GimpVector3 p[2*8], a, axis, scale;
   gint n=0,i;
   gdouble cx1,cy1,cx2,cy2;
   gfloat m[16], l, angle;
@@ -636,18 +810,18 @@ void draw_wireframe_cylinder(gint startx,gint starty,gint pw,gint ph)
   init_compute();
 
   scale = mapvals.scale;
-  gck_vector3_mul(&scale,0.5);
+  gimp_vector3_mul(&scale,0.5);
 
   l = mapvals.cylinder_length/2.0;
   angle = 0;
   
-  gck_vector3_set(&axis, 0.0,1.0,0.0);
+  gimp_vector3_set(&axis, 0.0,1.0,0.0);
   
   for (i=0;i<8;i++)
     {
       rotatemat(angle, &axis, m);     
 
-      gck_vector3_set(&a, mapvals.cylinder_radius,0.0,0.0);
+      gimp_vector3_set(&a, mapvals.cylinder_radius,0.0,0.0);
       
       vecmulmat(&p[i], &a, m);
       
@@ -665,7 +839,7 @@ void draw_wireframe_cylinder(gint startx,gint starty,gint pw,gint ph)
   for (i=0;i<16;i++)
     {
       vecmulmat(&a,&p[i],rotmat);
-      gck_vector3_add(&p[i],&a,&mapvals.position);
+      gimp_vector3_add(&p[i],&a,&mapvals.position);
     }
 
   /* Draw the box */
@@ -692,7 +866,8 @@ void draw_wireframe_cylinder(gint startx,gint starty,gint pw,gint ph)
   linetab[n].x1=-1;
 }
 
-void clear_wireframe(void)
+void
+clear_wireframe (void)
 {
   gint n=0;
   
