@@ -1,5 +1,5 @@
 /*
- * "$Id: despeckle.c,v 1.28 2000/02/04 15:12:11 mitch Exp $"
+ * "$Id: despeckle.c,v 1.34 2000/09/30 20:13:06 nicklamb Exp $"
  *
  *   Despeckle (adaptive median) filter for The GIMP -- an image manipulation
  *   program
@@ -46,6 +46,7 @@
 
 #include <stdio.h>
 #include <stdlib.h>
+#include <string.h>
 
 #include <gtk/gtk.h>
 
@@ -54,24 +55,25 @@
 
 #include "libgimp/stdplugins-intl.h"
 
+
 /*
  * Constants...
  */
 
-#define PLUG_IN_NAME		"plug_in_despeckle"
-#define PLUG_IN_VERSION		"1.3.2 - 17 May 1998"
-#define PREVIEW_SIZE		128
-#define SCALE_WIDTH		80
-#define ENTRY_WIDTH		40
-#define MAX_RADIUS		20
+#define PLUG_IN_NAME	 "plug_in_despeckle"
+#define PLUG_IN_VERSION	 "1.3.2 - 17 May 1998"
+#define PREVIEW_SIZE	 128
+#define SCALE_WIDTH	 80
+#define ENTRY_WIDTH	 40
+#define MAX_RADIUS	 20
 
-#define FILTER_ADAPTIVE		0x01
-#define FILTER_RECURSIVE	0x02
+#define FILTER_ADAPTIVE	 0x01
+#define FILTER_RECURSIVE 0x02
 
-#define despeckle_radius	(despeckle_vals[0])	/* Radius of filter */
-#define filter_type		(despeckle_vals[1])	/* Type of filter */
-#define black_level		(despeckle_vals[2])	/* Black level */
-#define white_level		(despeckle_vals[3])	/* White level */
+#define despeckle_radius (despeckle_vals[0])	/* Radius of filter */
+#define filter_type	 (despeckle_vals[1])	/* Type of filter */
+#define black_level	 (despeckle_vals[2])	/* Black level */
+#define white_level	 (despeckle_vals[3])	/* White level */
 
 /*
  * Local functions...
@@ -80,9 +82,9 @@
 static void	query (void);
 static void	run   (gchar   *name,
 		       gint     nparams,
-		       GParam  *param,
+		       GimpParam  *param,
 		       gint    *nreturn_vals,
-		       GParam **return_vals);
+		       GimpParam **return_vals);
 
 static void	despeckle (void);
 
@@ -103,7 +105,7 @@ static void	preview_scroll_callback   (void);
  * Globals...
  */
 
-GPlugInInfo PLUG_IN_INFO =
+GimpPlugInInfo PLUG_IN_INFO =
 {
   NULL,  /* init  */
   NULL,  /* quit  */
@@ -124,7 +126,7 @@ guchar	       *preview_src = NULL,	/* Source pixel rows */
 GtkObject      *hscroll_data,		/* Horizontal scrollbar data */
 	       *vscroll_data;		/* Vertical scrollbar data */
 
-GDrawable      *drawable = NULL;	/* Current image */
+GimpDrawable      *drawable = NULL;	/* Current image */
 gint		sel_x1,			/* Selection bounds */
 		sel_y1,
 		sel_x2,
@@ -157,35 +159,31 @@ MAIN ()
 static void
 query (void)
 {
-  static GParamDef	args[] =
+  static GimpParamDef	args[] =
   {
-    { PARAM_INT32,	"run_mode",	"Interactive, non-interactive" },
-    { PARAM_IMAGE,	"image",	"Input image" },
-    { PARAM_DRAWABLE,	"drawable",	"Input drawable" },
-    { PARAM_INT32,	"radius",	"Filter box radius (default = 3)" },
-    { PARAM_INT32,	"type",		"Filter type (0 = median, 1 = adaptive, 2 = recursive-median, 3 = recursive-adaptive)" },
-    { PARAM_INT32,	"black",	"Black level (0 to 255)" },
-    { PARAM_INT32,	"white",	"White level (0 to 255)" }
+    { GIMP_PDB_INT32,	"run_mode",	"Interactive, non-interactive" },
+    { GIMP_PDB_IMAGE,	"image",	"Input image" },
+    { GIMP_PDB_DRAWABLE,	"drawable",	"Input drawable" },
+    { GIMP_PDB_INT32,	"radius",	"Filter box radius (default = 3)" },
+    { GIMP_PDB_INT32,	"type",		"Filter type (0 = median, 1 = adaptive, 2 = recursive-median, 3 = recursive-adaptive)" },
+    { GIMP_PDB_INT32,	"black",	"Black level (0 to 255)" },
+    { GIMP_PDB_INT32,	"white",	"White level (0 to 255)" }
   };
-  static GParamDef	*return_vals = NULL;
-  static int		nargs        = sizeof(args) / sizeof(args[0]),
-			nreturn_vals = 0;
-
-  INIT_I18N();
+  static gint nargs = sizeof (args) / sizeof (args[0]);
 
   gimp_install_procedure (PLUG_IN_NAME,
-			  _("Despeckle filter, typically used to \'despeckle\' a photographic image."),
-			  _("This plug-in selectively performs a median or adaptive box filter on an image."),
+			  "Despeckle filter, typically used to \'despeckle\' "
+			  "a photographic image.",
+			  "This plug-in selectively performs a median or "
+			  "adaptive box filter on an image.",
 			  "Michael Sweet <mike@easysw.com>",
 			  "Copyright 1997-1998 by Michael Sweet",
 			  PLUG_IN_VERSION,
 			  N_("<Image>/Filters/Enhance/Despeckle..."),
 			  "RGB*, GRAY*",
-			  PROC_PLUG_IN,
-			  nargs,
-			  nreturn_vals,
-			  args,
-			  return_vals);
+			  GIMP_PLUGIN,
+			  nargs, 0,
+			  args, NULL);
 }
 
 
@@ -196,24 +194,24 @@ query (void)
 static void
 run (gchar   *name,		/* I - Name of filter program. */
      gint     nparams,		/* I - Number of parameters passed in */
-     GParam  *param,		/* I - Parameter values */
+     GimpParam  *param,		/* I - Parameter values */
      gint    *nreturn_vals,	/* O - Number of return values */
-     GParam **return_vals)	/* O - Return values */
+     GimpParam **return_vals)	/* O - Return values */
 {
-  GRunModeType	run_mode;	/* Current run mode */
-  GStatusType	status;		/* Return status */
-  GParam	*values;	/* Return values */
+  GimpRunModeType	run_mode;	/* Current run mode */
+  GimpPDBStatusType	status;		/* Return status */
+  GimpParam	*values;	/* Return values */
 
   /*
    * Initialize parameter data...
    */
 
-  status   = STATUS_SUCCESS;
+  status   = GIMP_PDB_SUCCESS;
   run_mode = param[0].data.d_int32;
 
-  values = g_new (GParam, 1);
+  values = g_new (GimpParam, 1);
 
-  values[0].type          = PARAM_STATUS;
+  values[0].type          = GIMP_PDB_STATUS;
   values[0].data.d_status = status;
 
   *nreturn_vals = 1;
@@ -237,7 +235,7 @@ run (gchar   *name,		/* I - Name of filter program. */
 
   switch (run_mode)
     {
-    case RUN_INTERACTIVE :
+    case GIMP_RUN_INTERACTIVE :
       INIT_I18N_UI();
       /*
        * Possibly retrieve data...
@@ -253,14 +251,14 @@ run (gchar   *name,		/* I - Name of filter program. */
 	return;
       break;
 
-    case RUN_NONINTERACTIVE:
+    case GIMP_RUN_NONINTERACTIVE:
       /*
        * Make sure all the arguments are present...
        */
 
       INIT_I18N();
       if (nparams < 4 || nparams > 7)
-	status = STATUS_CALLING_ERROR;
+	status = GIMP_PDB_CALLING_ERROR;
       else if (nparams == 4)
 	{
 	  despeckle_radius = param[3].data.d_int32;
@@ -291,7 +289,7 @@ run (gchar   *name,		/* I - Name of filter program. */
 	};
       break;
 
-    case RUN_WITH_LAST_VALS:
+    case GIMP_RUN_WITH_LAST_VALS:
       /*
        * Possibly retrieve data...
        */
@@ -301,7 +299,7 @@ run (gchar   *name,		/* I - Name of filter program. */
 	break;
 	
     default:
-      status = STATUS_CALLING_ERROR;
+      status = GIMP_PDB_CALLING_ERROR;
       break;;
     };
 
@@ -309,7 +307,7 @@ run (gchar   *name,		/* I - Name of filter program. */
    * Despeckle the image...
    */
 
-  if (status == STATUS_SUCCESS)
+  if (status == GIMP_PDB_SUCCESS)
     {
       if ((gimp_drawable_is_rgb(drawable->id) ||
 	   gimp_drawable_is_gray(drawable->id)))
@@ -331,19 +329,19 @@ run (gchar   *name,		/* I - Name of filter program. */
 	   * If run mode is interactive, flush displays...
 	   */
 
-	  if (run_mode != RUN_NONINTERACTIVE)
+	  if (run_mode != GIMP_RUN_NONINTERACTIVE)
 	    gimp_displays_flush ();
 
 	  /*
 	   * Store data...
 	   */
 
-	  if (run_mode == RUN_INTERACTIVE)
+	  if (run_mode == GIMP_RUN_INTERACTIVE)
 	    gimp_set_data (PLUG_IN_NAME,
 			   despeckle_vals, sizeof (despeckle_vals));
 	}
       else
-	status = STATUS_EXECUTION_ERROR;
+	status = GIMP_PDB_EXECUTION_ERROR;
     };
 
   /*
@@ -375,7 +373,7 @@ run (gchar   *name,		/* I - Name of filter program. */
 static void
 despeckle (void)
 {
-  GPixelRgn	src_rgn,	/* Source image region */
+  GimpPixelRgn	src_rgn,	/* Source image region */
 		dst_rgn;	/* Destination image region */
   guchar      **src_rows,	/* Source pixel rows */
 	       *dst_row,	/* Destination pixel row */
@@ -608,32 +606,14 @@ despeckle_dialog (void)
   GtkWidget *scrollbar;
   GtkWidget *button;
   GtkObject *adj;
-  gint     argc;
-  gchar	 **argv;
-  guchar  *color_cube;
-  gchar   *plugin_name;
+  gchar *plugin_name;
 
-  argc    = 1;
-  argv    = g_new (gchar *, 1);
-  argv[0] = g_strdup ("despeckle");
+  gimp_ui_init ("despeckle", TRUE);
 
-  gtk_init (&argc, &argv);
-  gtk_rc_parse (gimp_gtkrc ());
-  gdk_set_use_xshm (gimp_use_xshm ());
-
-  gtk_preview_set_gamma (gimp_gamma ());
-  gtk_preview_set_install_cmap (gimp_install_cmap ());
-  color_cube = gimp_color_cube ();
-  gtk_preview_set_color_cube (color_cube[0], color_cube[1],
-			      color_cube[2], color_cube[3]);
-
-  gtk_widget_set_default_visual (gtk_preview_get_visual ());
-  gtk_widget_set_default_colormap (gtk_preview_get_cmap ());
-
-  plugin_name = g_strdup_printf ("%s%s", _("Despeckle "), PLUG_IN_VERSION);
+  plugin_name = g_strdup_printf ("%s %s", _("Despeckle"), PLUG_IN_VERSION);
 
   dialog = gimp_dialog_new (plugin_name, "despeckle",
-			    gimp_plugin_help_func, "filters/despeckle.html",
+			    gimp_standard_help_func, "filters/despeckle.html",
 			    GTK_WIN_POS_MOUSE,
 			    FALSE, TRUE, FALSE,
 
@@ -874,7 +854,7 @@ preview_scroll_callback (void)
 static void
 preview_update (void)
 {
-  GPixelRgn	src_rgn;	/* Source image region */
+  GimpPixelRgn	src_rgn;	/* Source image region */
   guchar       *sort_ptr,	/* Current preview_sort value */
 	       *src_ptr,	/* Current source pixel */
 	       *dst_ptr;	/* Current destination pixel */
