@@ -17,7 +17,7 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- * $Id: gdyntext.c,v 1.30 2000/08/16 16:42:56 neo Exp $
+ * $Id: gdyntext.c,v 1.33 2000/10/03 20:50:41 mitch Exp $
  */
 
 #include "config.h"
@@ -132,7 +132,7 @@ gdt_run (gchar       *name,
 
   switch(run_mode) 
     {
-    case RUN_INTERACTIVE:
+    case GIMP_RUN_INTERACTIVE:
       memset (&oldvals, 0, sizeof(GdtVals));
       gimp_get_data ("plug_in_gdyntext", &oldvals);
 
@@ -158,13 +158,13 @@ gdt_run (gchar       *name,
 	return;
       break;
 
-    case RUN_NONINTERACTIVE:
+    case GIMP_RUN_NONINTERACTIVE:
 #ifdef DEBUG
       g_print ("%d\n", nparams);
 #endif
       if (nparams != 11) 
 	{
-	  values[0].data.d_status = STATUS_CALLING_ERROR;
+	  values[0].data.d_status = GIMP_PDB_CALLING_ERROR;
 	  return;
 	} 
       else 
@@ -183,7 +183,7 @@ gdt_run (gchar       *name,
 	}
       break;
 
-    case RUN_WITH_LAST_VALS:
+    case GIMP_RUN_WITH_LAST_VALS:
       gimp_get_data ("plug_in_gdyntext", &gdtvals);
       gdtvals.image_id		 = param[1].data.d_image;
       gdtvals.drawable_id	 = param[2].data.d_drawable;
@@ -194,7 +194,7 @@ gdt_run (gchar       *name,
   
   gdt_render_text (&gdtvals);
 
-  if (run_mode == RUN_INTERACTIVE)
+  if (run_mode == GIMP_RUN_INTERACTIVE)
     {
       gdtvals.valid = TRUE;
       gimp_set_data ("plug_in_gdyntext", &gdtvals, sizeof(GdtVals));
@@ -304,8 +304,8 @@ gdt_save (GdtVals *data)
   g_free(text);
   
   parasite = gimp_parasite_new (GDYNTEXT_PARASITE,
-				PARASITE_PERSISTENT | PARASITE_UNDOABLE, strlen(lname), lname);
-  gimp_drawable_attach_parasite (data->drawable_id, parasite);
+				GIMP_PARASITE_PERSISTENT | GIMP_PARASITE_UNDOABLE, strlen(lname), lname);
+  gimp_drawable_parasite_attach (data->drawable_id, parasite);
   gimp_parasite_free (parasite);
   
   if (!data->change_layer_name) 
@@ -335,7 +335,7 @@ void
 gdt_render_text_p (GdtVals  *data, 
 		   gboolean  show_progress)
 {
-  gint layer_ox, layer_oy, i, nret_vals, xoffs;
+  gint layer_ox, layer_oy, i, xoffs;
   gint32 layer_f, selection_empty, selection_channel = -1;
   gint32 text_width, text_height = 0;
   gint32 text_ascent, text_descent;
@@ -346,7 +346,6 @@ gdt_render_text_p (GdtVals  *data,
   gint32 font_size_type;
   gchar **text_xlfd, **text_lines;
   gint32 *text_lines_w;
-  GimpParam      *ret_vals;
   GimpParamColor  old_color, text_color;
   
   if (show_progress)
@@ -360,11 +359,7 @@ gdt_render_text_p (GdtVals  *data,
   if (!selection_empty) 
     {
       /* there is an active selection to save */
-      ret_vals = gimp_run_procedure ("gimp_selection_save", &nret_vals,
-				     GIMP_PDB_IMAGE, data->image_id, GIMP_PDB_END);
-      selection_channel = ret_vals[1].data.d_int32;
-      gimp_destroy_params (ret_vals, nret_vals);
-      
+      selection_channel = gimp_selection_save (data->image_id);
       gimp_selection_none (data->image_id);
     }
 
@@ -447,7 +442,7 @@ gdt_render_text_p (GdtVals  *data,
       data->layer_id = data->drawable_id = gimp_layer_new (data->image_id,
 							   _("GDynText Layer"), layer_width, layer_height,
 							   (GimpImageType)(gimp_image_base_type (data->image_id) * 2 + 1),
-							   100.0, NORMAL_MODE);
+							   100.0, GIMP_NORMAL_MODE);
       gimp_layer_add_alpha (data->layer_id);
       gimp_image_add_layer (data->image_id, data->layer_id, 0);
       gimp_image_set_active_layer (data->image_id, data->layer_id);
@@ -571,6 +566,7 @@ gdt_render_text_p (GdtVals  *data,
       break;
     case LA_NONE:
     default:
+      break;
     }
   
   gimp_layer_set_preserve_transparency (data->layer_id, 1);
@@ -578,10 +574,7 @@ gdt_render_text_p (GdtVals  *data,
   /* restore old selection if any */
   if (selection_empty == FALSE) 
     {
-      ret_vals = gimp_run_procedure ("gimp_selection_load", &nret_vals,
-				     GIMP_PDB_IMAGE, data->image_id,
-				     GIMP_PDB_CHANNEL, selection_channel, GIMP_PDB_END);
-      gimp_destroy_params (ret_vals, nret_vals);
+      gimp_selection_load (selection_channel);
       gimp_image_remove_channel (data->image_id, selection_channel);
     }
 
